==> kubernetes-model-apiextensions-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceDefinitionStatusBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceDefinitionStatusBuilder() {
        this(true);
    }

    public CustomResourceDefinitionStatusBuilder(Boolean validationEnabled) {
        this(new CustomResourceDefinitionStatus(), validationEnabled);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CustomResourceDefinitionStatus(), validationEnabled);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus instance) {
        this(fluent, instance, true);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAcceptedNames(instance.getAcceptedNames()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withStoredVersions(instance.getStoredVersions()); 
        this.validationEnabled = validationEnabled; 
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus instance) {
        this(instance,true);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAcceptedNames(instance.getAcceptedNames()); 
        this.withConditions(instance.getConditions()); 
        this.withStoredVersions(instance.getStoredVersions()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus build() {
        CustomResourceDefinitionStatus buildable = new CustomResourceDefinitionStatus(fluent.getAcceptedNames(),fluent.getConditions(),fluent.getStoredVersions());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceDefinitionStatusBuilder that = (CustomResourceDefinitionStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apiextensions-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceDefinitionStatusBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceDefinitionStatusBuilder() {
        this(true);
    }

    public CustomResourceDefinitionStatusBuilder(Boolean validationEnabled) {
        this(new CustomResourceDefinitionStatus(), validationEnabled);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CustomResourceDefinitionStatus(), validationEnabled);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus instance) {
        this(fluent, instance, true);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAcceptedNames(instance.getAcceptedNames()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withStoredVersions(instance.getStoredVersions()); 
        this.validationEnabled = validationEnabled; 
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus instance) {
        this(instance,true);
    }

    public CustomResourceDefinitionStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAcceptedNames(instance.getAcceptedNames()); 
        this.withConditions(instance.getConditions()); 
        this.withStoredVersions(instance.getStoredVersions()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus build() {
        CustomResourceDefinitionStatus buildable = new CustomResourceDefinitionStatus(fluent.getAcceptedNames(),fluent.getConditions(),fluent.getStoredVersions());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceDefinitionStatusBuilder that = (CustomResourceDefinitionStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
